.. _github-stats_3-10-7:

GitHub statistics for 3.10.7 (Oct 08, 2025)
===========================================

GitHub statistics for 2024/12/14 (tag: v3.10.0) - 2025/10/08

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 4 issues and merged 16 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/105?closed=1>`__

The following 32 authors contributed 422 commits.

* Aasma Gupta
* AASMA GUPTA
* Antony Lee
* Christine P. Chai
* David Stansby
* dependabot[bot]
* Elliott Sales de Andrade
* G.D. McBain
* Greg Lucas
* hannah
* hu-xiaonan
* Ian Thomas
* Inês Cachola
* Jody Klymak
* Jouni K. Seppänen
* Khushi_29
* Kyle Sunden
* Lumberbot (aka Jack)
* N R Navaneet
* Nathan G. Wiseman
* Oscar Gustafsson
* Praful Gulani
* Qian Zhang
* Raphael Erik Hviding
* Roman
* Ruth Comer
* saikarna913
* Scott Shambaugh
* Thomas A Caswell
* Tim Heap
* Tim Hoffmann
* Trygve Magnus Ræder

GitHub issues and pull requests:

Pull Requests (16):

* :ghpull:`30628`: Backport PR #30626 on branch v3.10.x (MNT: Fix new F401 unused imports warnings)
* :ghpull:`30626`: MNT: Fix new F401 unused imports warnings
* :ghpull:`30589`: Backport PR #29745: Use PEP8 style method and function names from
* :ghpull:`30614`: Backport PR #30612 on branch v3.10.x (MNT: update black pin)
* :ghpull:`30612`: MNT: update black pin
* :ghpull:`30572`: Backport PR #30571 on branch v3.10.x (CI: remove macos13)
* :ghpull:`30571`: CI: remove macos13
* :ghpull:`30570`: Backport PR #30558 on branch v3.10.x (Fix stubtest with mypy 18)
* :ghpull:`30558`: Fix stubtest with mypy 18
* :ghpull:`30540`: Backport PR #30539 on branch v3.10.x (Fix scale_unit/scale_units typo in quiver docs)
* :ghpull:`30539`: Fix scale_unit/scale_units typo in quiver docs
* :ghpull:`30518`: Backport PR #30497 on branch v3.10.x (TST: Use a temporary directory for test_save_figure_return)
* :ghpull:`30497`: TST: Use a temporary directory for test_save_figure_return
* :ghpull:`30506`: Backport PR #30490 on branch v3.10.x (Fix SVG rendering error in def update_background)
* :ghpull:`30490`: Fix SVG rendering error in def update_background
* :ghpull:`30494`: Backport PR #30492 on branch v3.10.x (DOC: pytz link should be from PyPI)

Issues (4):

* :ghissue:`30611`: [MNT]: black version
* :ghissue:`30551`: [Bug]: Mypy stubtest failure on disjoint_base
* :ghissue:`30493`: [Bug]: test_save_figure_return seems flaky
* :ghissue:`30485`: [Bug]: figures with SpanSelector(..., useblit=True) can't be saved to SVG or PDF
